#
# spec file for package python-pyowm
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pyowm
Version:        2.9.0
Release:        2.50
Summary:        A Python wrapper around the OpenWeatherMap web API
License:        MIT
Group:          Development/Languages/Python
URL:            http://github.com/csparpa/pyowm
Source:         https://files.pythonhosted.org/packages/source/p/pyowm/pyowm-%{version}.tar.gz
Source99:       https://raw.githubusercontent.com/csparpa/pyowm/master/LICENSE
BuildRequires:  %{python_module requests >= 2.18.2}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-geojson >= 2.3.0
Requires:       python-requests >= 2.18.2
BuildArch:      noarch
%python_subpackages

%description
PyOWM is a client Python wrapper library for the OpenWeatherMap web API.
It allows quick and easy consumption of OWM weather data from Python
applications via a simple object model and in a human-friendly fashion.

%prep
%setup -q -n pyowm-%{version}
cp %{SOURCE99} .

# Remove shebang line:
sed -i '1d' pyowm/__init__.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/*

%changelog
* Mon Jul 30 2018 tchvatal@suse.com
- Version restrict requirements
- Drop devel dependency
* Sat Jul 28 2018 alarrosa@suse.com
- Update to version 2.9.0
  * New features:
  * Support for Weather Alerts
  * Support for UV Index Forecast and History
  * Logos for the project have been introduced!
  * Support for Python 3.7
  * Support for Pipfile
  * Enhancements:
  * Heavily improved readthedocs documentation
  * Now PyOWM talks to OWM APIs over SSL
  * Refactored out one single consistent HTTP base client, based on requests
  * Refactored UV API and Air Pollution API code to dedicated packages
  * Bugfixes:
  * issue on requests==2.19.1 incompatibility
  * now printing on console the detailed weather status (language-sensitive)
    instead of generic english-based weather status
  * fixed broken links in a few Markdown docs
  * Deprecations introduced:
  * will be removed on 3.0.0: OWM25.weather_at_stations_in_bbox, OWM25.weather_at_station
  * Note: parsers were moved to a "parsers" submodule
* Sun Mar  4 2018 alarrosa@suse.com
- Fix LICENSE url
* Fri Jan  5 2018 alarrosa@suse.com
- Update to version 2.8.0
  * New features:
  * introduced support for Stations API 3.0
  * new methods for Forecaster class: will_have_clear, when_clear,
    will_be_clear_at
  * new light Docker images based on Alpine Linux
  * Enhancements:
  * In the moment Forecast objects are created, their Weather objects having
    reference timestamps prior to that moment are discarded (this means:
    you only get real forecasts!)
  * Introduced requests as only PyOWM dependency: requests>=2.18.2,<2.19
  * Bugfixes:
  * issue on city_id_registry read behaviour on Windows
  * issue on parsing Location objects
  * Deprecations introduced:
  * will be removed on 3.0.0: forecaster.Forecaster.will_have_sun,
    forecaster.Forecaster.when_sun and
    forecaster.Forecaster.will_be_sunny_at
* Tue Sep  5 2017 alarrosa@suse.com
- Update to version 2.7.1:
  * New features:
  * introduced support for Sulphur Dioxide (SO2) and Nitric Dioxide
    (NO2): new methods owm25.no2index_around_coords and
    owm25.so2index_around_coords
  * implemented wind speed units specification (imperial/metric)
  * Bugfixes:
  * updated weather history endpoint (was broken)
  * fix bug about data parsing at station_at_coords and weather_at_station
    methods
  * now the deg attribute is correctly parsed from 16 day forecast
    weather data items
  * fix bug on printing Unicode upon library exceptions
  * fix handling of Weather objects parsing (it was failing whenever
    some data wasn't provided by OWM)
  * Enhancements:
  * shrinked city ID files size by 60%% (via compression)
  * reported in the Wiki a list of known projects that use PyOWM
  * integrated the Say Thanks! hook
  * introduced CONTRIBUTING.md and CODE_OF_CONDUCT.md files, thus welcoming
    GitHub's suggested best practices for building better open source
    communities
  * introduced installation tests
  * improved integrations tests organization and running
  * Breaking changes:
  * OWM decided to change the syntax of API endpoint for fetching UV data
    and its format in a non-retrocompatible manner. This results into
    UVIndex object entity fields changing, as well as the corresponding
    OWM25 method signature (owm25.uvindex_around_coords).
- Use singlespec macros
* Wed Feb 22 2017 toms@opensuse.org
- First public release 2.6.1 on OBS
